<h1 align=center>AqVISA Library</h1>

[![License](https://img.shields.io/badge/License-BSD_2--Clause-orange.svg)](https://opensource.org/licenses/BSD-2-Clause)
![PyPI](https://img.shields.io/pypi/v/aqvisa?label=pypi%20package)

AqVISA offers an intuitive interface for seamless management of controlling our applications. This Python package providing higher level management to AqVISA libraries.

- [Installation](Installation)
- [Examples](Examples)

## Installation

To install aqvisa, you can use the following command:

```bash
pip install aqvisa
```

## Examples

| **Use Case** | **Description** |
| ------------ | --------------- |
| [Basic Write / Read](https://github.com/acute-technology-inc/aqvisa-python/blob/main/examples/simple.py) | Demonstrates basic usage | 
